@@ -25,7 +25,7 @@ namespace MailTransport
 {
 class ServerTest;
 }
-namespace KIdentityManagement
+namespace KIdentityManagementWidgets
 {
 class IdentityCombo;
 }
@@ -54,7 +54,7 @@ public:
      */
     ~SetupServer() override;
 
-    Q_REQUIRED_RESULT bool shouldClearCache() const;
+    [[nodiscard]] bool shouldClearCache() const;
 
 private:
     /**
@@ -74,7 +74,7 @@ private:
     bool m_subscriptionsChanged = false;
     bool m_shouldClearCache = false;
     QString m_vacationFileName;
-    KIdentityManagement::IdentityCombo *m_identityCombobox = nullptr;
+    KIdentityManagementWidgets::IdentityCombo *m_identityCombobox = nullptr;
     QString m_oldResourceName;
     QRegularExpressionValidator mValidator;
     Akonadi::Collection mOldTrash;
@@ -83,7 +83,7 @@ private:
 
 private Q_SLOTS:
     void slotTest();
-    void slotFinished(const QVector<int> &testResult);
+    void slotFinished(const QList<int> &testResult);
     void slotCustomSieveChanged();
 
     void slotServerChanged();
